django-iprestrict
=================
[![Build Status](https://travis-ci.org/muccg/django-iprestrict.png?branch=master)](https://travis-ci.org/muccg/django-iprestrict) [![Coverage Status](https://coveralls.io/repos/muccg/django-iprestrict/badge.png)](https://coveralls.io/r/muccg/django-iprestrict) [![Code Health](https://landscape.io/github/muccg/django-iprestrict/master/landscape.svg?style=flat)](https://landscape.io/github/muccg/django-iprestrict/master) [![PyPI](https://img.shields.io/pypi/v/django-iprestrict.svg)]()

Django app + middleware to restrict access to all or sections of a Django project by client IP ranges.
